#!/bin/sh
# emacspeak - execute emacs with speech enhancements
#$Id: emacspeak.sh.def,v 20.0 2004/05/01 01:16:25 raman Exp $
    if [ -f /etc/emacspeak.conf ]
    then
    . /etc/emacspeak.conf
fi

if [ -f $HOME/.emacs ]
then
	INITSTR="-l $HOME/.emacs"
fi

CL_ALL=""
for CL in $* ; do
	if [ "$CL" = "-o" ]; then
		DTK_PROGRAM=stereo-outloud
		export DTK_PROGRAM
                elif [ "$CL" = "-d" ]; then
		DTK_PROGRAM=dtk-soft
		export DTK_PROGRAM
	elif [ "$CL" = "-q" ]; then
		INITSTR=""
	else
		CL_ALL="$CL_ALL $CL"
	fi
done


EMACS_UNIBYTE=1
export EMACS_UNIBYTE
exec emacs -q -l <emacspeak-dir>/emacspeak-setup.el $INITSTR $CL_ALL
